/*
 * Copyright (c) 2024 Red Hat, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *     * Redistributions of source code must retain the above
 *       copyright notice, this list of conditions and the
 *       following disclaimer.
 *     * Redistributions in binary form must reproduce the
 *       above copyright notice, this list of conditions and
 *       the following disclaimer in the documentation and/or
 *       other materials provided with the distribution.
 *     * The names of contributors to this software may not be
 *       used to endorse or promote products derived from this
 *       software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 *
 * Author: Daiki Ueno
 */

#ifndef P11_KIT_VERSION_H
#define P11_KIT_VERSION_H

#ifdef __cplusplus
extern "C" {
#endif

#define P11_KIT_VERSION_MAJOR (0)
#define P11_KIT_VERSION_MINOR (26)
#define P11_KIT_VERSION_MICRO (2)

#define P11_KIT_CHECK_VERSION(major, minor, micro)	\
	(P11_KIT_VERSION_MAJOR > (major) ||		\
	 (P11_KIT_VERSION_MAJOR == (major) &&		\
	  P11_KIT_VERSION_MINOR > (minor)) ||		\
	 (P11_KIT_VERSION_MAJOR == (major) &&		\
	  P11_KIT_VERSION_MINOR == (minor) &&		\
	  P11_KIT_VERSION_MICRO >= (micro)))

int p11_kit_check_version (int major, int minor, int micro);

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* P11_KIT_VERSION_H */
